@@ -17,10 +17,6 @@ import numpy as N
 import scipy.ndimage as nd
 from .image import *
 from . import mylogger
-try:
-    from astropy.io import fits as pyfits
-except ImportError as err:
-    import pyfits
 from . import functions as func
 from .output import write_islands
 from .readimage import Op_readimage
@@ -28,6 +24,7 @@ from .preprocess import Op_preprocess
 from .rmsimage import Op_rmsimage
 from .threshold import Op_threshold
 from .collapse import Op_collapse
+import os
 
 
 class Op_islands(Op):
@@ -51,12 +48,16 @@ class Op_islands(Op):
 
         minsize = opts.minpix_isl
         if minsize is None:
-            minsize = int(img.pixel_beamarea()/3.0) # 1/3 of beam area in pixels
+            minsize = int(img.pixel_beamarea()/3.0)  # 1/3 of beam area in pixels
             if minsize < 6:
-                minsize = 6 # Need at least 6 pixels to obtain good fits
+                minsize = 6  # Need at least 6 pixels to obtain good fits
             mylogger.userinfo(mylog, "Minimum number of pixels per island", '%i' %
-                          minsize)
+                              minsize)
         img.minpix_isl = minsize
+        maxsize = opts.maxpix_isl
+        if maxsize is None:
+            maxsize = N.inf
+        img.maxpix_isl = maxsize
 
         if opts.detection_image != '':
             # Use a different image for island detection. The detection
@@ -84,19 +85,36 @@ class Op_islands(Op):
             if det_shape != ch0_shape:
                 raise RuntimeError("Detection image shape does not match that of input image.")
 
+            # Save the rms and mean maps derived from the detection image
+            img.detection_mean_arr = det_img.mean_arr
+            img.detection_rms_arr = det_img.rms_arr
+
             # Run through islands and correct the image and rms, mean and max values
-            img.island_labels = det_img.island_labels
             corr_islands = []
             mean_map = img.mean_arr
             rms_map = img.rms_arr
             for i, isl in enumerate(det_img.islands):
-                islcp = isl.copy(img.pixel_beamarea(), image=ch0_map[isl.bbox], mean=mean_map[isl.bbox], rms=rms_map[isl.bbox])
+                islcp = isl.copy(img.pixel_beamarea(), image=ch0_map[tuple(isl.bbox)], mean=mean_map[tuple(isl.bbox)], rms=rms_map[tuple(isl.bbox)])
                 islcp.island_id = i
                 corr_islands.append(islcp)
             img.islands = corr_islands
             img.nisl = len(img.islands)
             img.pyrank = det_img.pyrank
             img.minpix_isl = det_img.minpix_isl
+
+            if opts.savefits_det_rmsim or opts.output_all:
+                resdir = os.path.join(img.basedir, 'background')
+                os.makedirs(resdir, exist_ok=True)
+                func.write_image_to_file(img.use_io, img.imagename + '.detection_rmsd_I.fits',
+                                         img.detection_rms_arr, img, resdir)
+                mylog.info('%s %s' % ('Writing ', os.path.join(resdir, img.imagename+'.detection_rmsd_I.fits')))
+            if opts.savefits_det_meanim or opts.output_all:
+                resdir = os.path.join(img.basedir, 'background')
+                os.makedirs(resdir, exist_ok=True)
+                func.write_image_to_file(img.use_io, img.imagename + '.detection_mean_I.fits',
+                                         img.detection_mean_arr, img, resdir)
+                mylog.info('%s %s' % ('Writing ', os.path.join(resdir, img.imagename+'.detection_mean_I.fits')))
+
             mylogger.userinfo(mylog, "\nContinuing processing using primary image")
         else:
             if opts.src_ra_dec is not None:
@@ -115,14 +133,18 @@ class Op_islands(Op):
             for i, isl in enumerate(img.islands):
                 isl.island_id = i
                 pyrank[tuple(isl.bbox)] += N.invert(isl.mask_active) * (i + 1)
-            pyrank -= 1 # align pyrank values with island ids and set regions outside of islands to -1
-
-            if opts.output_all: write_islands(img)
-            if opts.savefits_rankim:
-                func.write_image_to_file(img.use_io, img.imagename + '_pyrank.fits', pyrank, img)
+            pyrank -= 1  # align pyrank values with island ids and set regions outside of islands to -1
 
             img.pyrank = pyrank
 
+        if opts.output_all:
+            write_islands(img)
+        if opts.savefits_rankim or opts.output_all:
+            resdir = os.path.join(img.basedir, 'misc')
+            os.makedirs(resdir, exist_ok=True)
+            func.write_image_to_file(img.use_io, img.imagename + '_pyrank.fits', img.pyrank, img, resdir)
+            mylog.info('%s %s' % ('Writing ', os.path.join(resdir, img.imagename+'_pyrank.fits')))
+
         img.completed_Ops.append('islands')
         return img
 
@@ -149,114 +171,101 @@ class Op_islands(Op):
 
         Function returns a list of Island objects.
         """
-        ### islands detection
-        mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Islands")
-
+        # Islands detection
         image = img.ch0_arr
         mask = img.mask_arr
         rms = img.rms_arr
         mean = img.mean_arr
         thresh_isl = opts.thresh_isl
         thresh_pix = img.thresh_pix
-        clipped_mean = img.clipped_mean
-        saverank = opts.savefits_rankim
 
-                        # act_pixels is true if significant emission
+        # Here act_pixels is true if significant emission
         if img.masked:
             act_pixels = ~(mask.copy())
             act_pixels[~mask] = (image[~mask]-mean[~mask])/thresh_isl >= rms[~mask]
         else:
             act_pixels = (image-mean)/thresh_isl >= rms
 
-                        # dimension of image
+        # Find dimension of image
         rank = len(image.shape)
-                        # generates matrix for connectivity, in this case, 8-conn
+        # Generates matrix for connectivity, in this case, 8-conn
         connectivity = nd.generate_binary_structure(rank, rank)
-                        # labels = matrix with value = (initial) island number
+        # Here labels = matrix with value = (initial) island number
         labels, count = nd.label(act_pixels, connectivity)
-                        # slices has limits of bounding box of each such island
+        # Here slices has limits of bounding box of each such island
         slices = nd.find_objects(labels)
         img.island_labels = labels
 
-        ### apply cuts on island size and peak value
+        # Apply cuts on island size and peak value
         pyrank = N.zeros(image.shape, dtype=N.int32)
         res = []
-        islid = 0
         for idx, s in enumerate(slices):
-            idx += 1 # nd.labels indices are counted from 1
-                        # number of pixels inside bounding box which are in island
-            isl_size = (labels[s] == idx).sum()
+            idx += 1  # nd.labels indices are counted from 1
+            isl_size = (labels[s] == idx).sum()  # number of pixels inside bounding box which are in island
             isl_peak = nd.maximum(image[s], labels[s], idx)
-            isl_maxposn = tuple(N.array(N.unravel_index(N.nanargmax(image[s]), image[s].shape))+\
-                          N.array((s[0].start, s[1].start)))
-            if (isl_size >= img.minpix_isl) and (isl_peak - mean[isl_maxposn])/thresh_pix > rms[isl_maxposn]:
+            isl_maxposn = tuple(N.array(N.unravel_index(N.nanargmax(image[s]), image[s].shape)) +
+                                N.array((s[0].start, s[1].start)))
+            if (isl_size >= img.minpix_isl) and (isl_size <= img.maxpix_isl) and (isl_peak - mean[isl_maxposn])/thresh_pix > rms[isl_maxposn]:
                 isl = Island(image, mask, mean, rms, labels, s, idx, img.pixel_beamarea())
                 res.append(isl)
                 pyrank[tuple(isl.bbox)] += N.invert(isl.mask_active)*idx // idx
 
         return res
 
-
     def coords_to_isl(self, img, opts):
         """Construct islands around given coordinates with given size.
 
         Returns a list of island objects.
         """
-        mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Islands")
-
-        coords = opts.src_ra_dec # list of RA and Dec tuples
+        coords = opts.src_ra_dec  # list of RA and Dec tuples
         isl_radius_pix = opts.src_radius_pix
         if isl_radius_pix is None:
-            isl_radius_pix = img.beam2pix(img.beam)[0] # twice beam major axis radius at half max (= FWHM)
+            isl_radius_pix = img.beam2pix(img.beam)[0]  # twice beam major axis radius at half max (= FWHM)
 
         res = []
         for idx, coord in enumerate(coords):
-            idx += 1 # nd.labels indices are counted from 1
+            idx += 1  # nd.labels indices are counted from 1
             isl_posn_pix = img.sky2pix(coord)
             image = img.ch0_arr
             mask = img.mask_arr
             rms = img.rms_arr
             mean = img.mean_arr
-            labels = func.make_src_mask(image.shape,
-                        isl_posn_pix, isl_radius_pix)
+            labels = func.make_src_mask(image.shape, isl_posn_pix, isl_radius_pix)
             if img.masked:
                 aper_mask = N.where(labels.astype(bool) & ~mask)
             else:
                 aper_mask = N.where(labels.astype(bool))
-            if N.size(aper_mask) > img.minpix_isl:
+            if N.size(aper_mask) >= img.minpix_isl and N.size(aper_mask) <= img.maxpix_isl:
                 labels[aper_mask] = idx
                 s = [slice(max(0, isl_posn_pix[0] - isl_radius_pix - 1),
                      min(image.shape[0], isl_posn_pix[0] + isl_radius_pix + 1)),
                      slice(max(0, isl_posn_pix[1] - isl_radius_pix - 1),
                      min(image.shape[1], isl_posn_pix[1] + isl_radius_pix + 1))]
-                isl = Island(image, mask, mean, rms, labels, s, idx,
-                        img.pixel_beamarea())
+                isl = Island(image, mask, mean, rms, labels, s, idx, img.pixel_beamarea())
                 res.append(isl)
         return res
 
-
     def setpara_bdsm(self, img, det_file):
-        from types import ClassType, TypeType
 
-        chain=[Op_readimage(), Op_collapse(), Op_preprocess, Op_rmsimage(),
-                Op_threshold(), Op_islands()]
+        chain = [Op_readimage(), Op_collapse(), Op_preprocess, Op_rmsimage(),
+                 Op_threshold(), Op_islands()]
         opts = img.opts.to_dict()
         opts['filename'] = det_file
         opts['detection_image'] = ''
         opts['polarisation_do'] = False
+        opts['rmsmean_map_filename'] = opts['rmsmean_map_filename_det']
+        opts['det_rmsmean_map_filename'] = None
 
         ops = []
         for op in chain:
-          if isinstance(op, (ClassType, TypeType)):
-            ops.append(op())
-          else:
-            ops.append(op)
+            if isinstance(op, type):
+                ops.append(op())
+            else:
+                ops.append(op)
 
         return ops, opts
 
 
-from .image import *
-
 class Island(object):
     """Instances of this class represent islands of emission in the image.
 
@@ -285,7 +294,7 @@ class Island(object):
                                       colname='Coeff_matrix', units=None)
 
         if not copy:
-            ### we make bbox slightly bigger
+            # We make bbox slightly bigger
             self.oldbbox = bbox
             self.oldidx = idx
             bbox = self.__expand_bbox(bbox, img.shape)
@@ -294,7 +303,7 @@ class Island(object):
             bbox_rms_im = rms[tuple(bbox)]
             bbox_mean_im = mean[tuple(bbox)]
 
-            ### create (inverted) masks
+            # Create (inverted) masks
             # Note that mask_active is the island mask; mask_noisy marks only
             # the noisy pixels in the island image. If you want to mask the
             # noisy pixels, set the final mask to:
@@ -303,7 +312,7 @@ class Island(object):
             noise_mask = (labels[tuple(bbox)] == 0)
             N.logical_or(noise_mask, isl_mask, noise_mask)
 
-            ### invert masks
+            # Invert masks
             N.logical_not(isl_mask, isl_mask)
             N.logical_not(noise_mask, noise_mask)
             if isinstance(mask, N.ndarray):
@@ -321,7 +330,7 @@ class Island(object):
             self.oldbbox = bbox
             self.oldidx = idx
 
-        ### finish initialization
+        # Finish initialization
         isl_size = N.sum(~isl_mask)
         self.island_id = idx
         self.bbox = bbox
@@ -333,20 +342,20 @@ class Island(object):
         self.size_active = isl_size
         self.max_value = N.max(self.image[~self.mask_active])
         in_bbox_and_unmasked = N.where(~N.isnan(bbox_rms_im))
-        self.rms  = bbox_rms_im[in_bbox_and_unmasked].mean()
+        self.rms = bbox_rms_im[in_bbox_and_unmasked].mean()
         in_bbox_and_unmasked = N.where(~N.isnan(bbox_mean_im))
-        self.mean  = bbox_mean_im[in_bbox_and_unmasked].mean()
-        self.islmean  = bbox_mean_im[in_bbox_and_unmasked].mean()
+        self.mean = bbox_mean_im[in_bbox_and_unmasked].mean()
+        self.islmean = bbox_mean_im[in_bbox_and_unmasked].mean()
         self.total_flux = N.nansum(self.image[in_bbox_and_unmasked])/beamarea
-        pixels_in_isl = N.sum(~N.isnan(self.image[self.mask_active])) # number of unmasked pixels assigned to current island
-        self.total_fluxE = func.nanmean(bbox_rms_im[in_bbox_and_unmasked]) * N.sqrt(pixels_in_isl/beamarea) # Jy
+        pixels_in_isl = N.sum(~N.isnan(self.image[self.mask_active]))  # number of unmasked pixels assigned to current island
+        self.total_fluxE = func.nanmean(bbox_rms_im[in_bbox_and_unmasked]) * N.sqrt(pixels_in_isl/beamarea)  # Jy
         self.border = self.get_border()
         self.gaul = []
+        self.fgaul = []
         self.sources = []
         self.gresid_mean = 0.0
         self.gresid_rms = 0.0
 
-
     def __setstate__(self, state):
         """Needed for multiprocessing"""
         self.mean = state['mean']
@@ -379,7 +388,7 @@ class Island(object):
         state['bbox'] = self.bbox
         return state
 
-    ### do map etc in case of ndim image
+    # Do map etc in case of ndim image
     def __expand_bbox(self, bbox, shape):
         """Expand bbox of the image by 1 pixel"""
         def __expand(bbox, shape):
@@ -395,7 +404,7 @@ class Island(object):
         if mean is None:
             mean = N.zeros(mask.shape, dtype=N.float32) + self.mean
         if rms is None:
-            rms =  N.zeros(mask.shape, dtype=N.float32) + self.rms
+            rms = N.zeros(mask.shape, dtype=N.float32) + self.rms
 
         bbox = self.bbox
         idx = self.oldidx
