@@ -366,21 +366,9 @@ def write_fits_list(img, filename=None, sort_by='index', objtype='gaul',
     """ Write as FITS binary table.
     """
     from . import mylogger
-    from distutils.version import StrictVersion
-    try:
-        from astropy.io import fits as pyfits
-        use_header_update = False
-        use_from_columns = True
-    except ImportError:
-        import pyfits
-        if StrictVersion(pyfits.__version__) < StrictVersion('3.1'):
-            use_header_update = True
-            use_from_columns = False
-        else:
-            use_header_update = False
-            use_from_columns = True
     import os
     import numpy as N
+    from astropy.io import fits as pyfits
     from ._version import __version__
 
     mylog = mylogger.logging.getLogger("PyBDSM."+img.log+"Output")
@@ -416,7 +404,7 @@ def write_fits_list(img, filename=None, sort_by='index', objtype='gaul',
                                                               incl_aper=incl_aper,
                                                               incl_empty=incl_empty,
                                                               nmax=nmax, nchan=img.nchan)
-    out_list = make_fits_list(img, outl, objtype=objtype, nmax=nmax, incl_empty=incl_empty,incl_chan=incl_chan)
+    out_list = make_fits_list(img, outl, objtype=objtype, nmax=nmax, incl_empty=incl_empty, incl_chan=incl_chan)
     col_list = []
     for ind, col in enumerate(out_list):
         list1 = pyfits.Column(name=cnames[ind], format=cformats[ind],
@@ -425,10 +413,7 @@ def write_fits_list(img, filename=None, sort_by='index', objtype='gaul',
     if len(col_list) == 0:
         col_list = [pyfits.Column(name='Blank', format='1J')]
 
-    if use_from_columns:
-        tbhdu = pyfits.BinTableHDU.from_columns(col_list)
-    else:
-        tbhdu = pyfits.new_table(col_list)
+    tbhdu = pyfits.BinTableHDU.from_columns(col_list)
 
     if objtype == 'gaul':
         tbhdu.header.add_comment('Gaussian list for '+img.filename)
@@ -441,14 +426,9 @@ def write_fits_list(img, filename=None, sort_by='index', objtype='gaul',
     freq = "%.5e" % img.frequency
     tbhdu.header.add_comment('Reference frequency of the detection ("ch0") image: %s Hz' % freq)
     tbhdu.header.add_comment('Equinox : %s' % img.equinox)
-    if use_header_update:
-        tbhdu.header.update('INIMAGE', img.filename, 'Filename of image')
-        tbhdu.header.update('FREQ0', float(freq), 'Reference frequency')
-        tbhdu.header.update('EQUINOX', img.equinox, 'Equinox')
-    else:
-        tbhdu.header['INIMAGE'] = (img.filename, 'Filename of image')
-        tbhdu.header['FREQ0'] = (float(freq), 'Reference frequency')
-        tbhdu.header['EQUINOX'] = (img.equinox, 'Equinox')
+    tbhdu.header['INIMAGE'] = (img.filename, 'Filename of image')
+    tbhdu.header['FREQ0'] = (float(freq), 'Reference frequency')
+    tbhdu.header['EQUINOX'] = (img.equinox, 'Equinox')
 
     for key in img.header.keys():
         if key in ['HISTORY', 'COMMENT', '']:
@@ -1025,9 +1005,9 @@ def list_and_sort_gaussians(img, patch=None, root=None,
             # Unrecognized property --> Don't sort
             indx = list(range(len(gausindx)))
         for i, si in enumerate(indx):
-                outlist_sorted[0][i] = outlist[0][si]
-                outnames_sorted[0][i] = outnames[0][si]
-                patchnames_sorted = list(patchnames)
+            outlist_sorted[0][i] = outlist[0][si]
+            outnames_sorted[0][i] = outnames[0][si]
+            patchnames_sorted = list(patchnames)
     else:
         outlist_sorted = list(outlist)
         outnames_sorted = list(outnames)
@@ -1068,7 +1048,7 @@ def make_output_columns(obj, fits=False, objtype='gaul', incl_spin=False,
                  'deconv_size_sky', 'deconv_size_skyE',
                  'deconv_size_sky_uncorr', 'deconv_size_skyE_uncorr',
                  'total_flux_isl', 'total_flux_islE', 'rms',
-                 'mean', 'gresid_rms', 'gresid_mean',
+                 'mean', 'gresid_rms', 'gresid_mean', 'wave_rms', 'wave_mean',
                  'code']
     elif objtype == 'srl':
         if incl_aper:
