@@ -15,11 +15,13 @@ from __future__ import absolute_import
 
 import numpy as N
 from .image import *
-from .functions import read_image_from_file
+from . import functions as func
 from . import mylogger
 import sys
 import shutil
 import tempfile
+import time
+import os
 
 
 class Op_readimage(Op):
@@ -28,7 +30,6 @@ class Op_readimage(Op):
     Loads image and configures wcslib machinery for it.
     """
     def __call__(self, img):
-        import time, os
         mylog = mylogger.logging.getLogger("PyBDSM." + img.log + "Readimage")
 
         if img.opts.filename == '':
@@ -40,38 +41,31 @@ class Op_readimage(Op):
         # replacing the file name in opts with the '/' trimmed off.
         if img.opts.filename[-1] == '/':
             img.opts.filename = img.opts.filename[:-1]
+        img.filename = img.opts.filename
 
         # Determine indir if not explicitly given by user (in img.opts.indir)
         if img.opts.indir is None:
-            indir = os.path.dirname(img.opts.filename)
+            indir = os.path.dirname(img.filename)
             if indir == '':
                 indir = './'
             img.indir = indir
         else:
             img.indir = img.opts.indir
 
-        # Try to trim common extensions from filename and store various
-        # paths
-        root, ext = os.path.splitext(img.opts.filename)
-        if ext in ['.fits', '.FITS', '.image']:
-            fname = root
-        elif ext in ['.gz', '.GZ']:
-            root2, ext2 = os.path.splitext(root)
-            if ext2 in ['.fits', '.FITS', '.image']:
-                fname = root2
-            else:
-                fname = root
-        else:
-            fname = img.opts.filename
-        img.filename = img.opts.filename
-        img.parentname = fname
-        img.imagename = fname + '.pybdsm'
-        img.basedir = './' + fname + '_pybdsm/'
+        # Set up output paths, etc.
+        parentname, basedir = func.set_up_output_paths(img.opts)
+        img.parentname = parentname  # root name for constructing output files
+        img.imagename = img.parentname + '.pybdsf'  # root name of output images (e.g., rms image)
+        img.outdir = basedir  # path of parent output directory
+        img.basedir = os.path.join(basedir, img.parentname+'_pybdsf')  # used for opts.output_all
+        if img.opts.solnname is not None:
+            # Add solname (if any) to basedir
+            img.basedir += img.opts.solnname
 
         # Read in data and header
         img.use_io = ''
         image_file = os.path.basename(img.opts.filename)
-        result = read_image_from_file(image_file, img, img.indir)
+        result = func.read_image_from_file(image_file, img, img.indir)
         if result is None:
             raise RuntimeError("Cannot open file " + repr(image_file) + ". " + img._reason)
         else:
@@ -86,7 +80,7 @@ class Op_readimage(Op):
             img.do_cache = False
         if img.do_cache:
             mylog.info('Using disk caching.')
-            tmpdir = img.parentname+'_tmp'
+            tmpdir = os.path.join(img.outdir, img.parentname+'_tmp')
             if not os.path.exists(tmpdir):
                 os.makedirs(tmpdir)
             img._tempdir_parent = TempDir(tmpdir)
@@ -136,20 +130,14 @@ class Op_readimage(Op):
                 img.opts.opdir_overwrite = 'append'
             if opdir == 'append':
                 mylog.info('Appending output files to directory ' + img.basedir)
+                img.basedir = os.path.join(img.basedir, time.strftime("%d%b%Y_%H.%M.%S"))
             else:
                 mylog.info('Overwriting output files (if any) in directory ' + img.basedir)
                 if os.path.isdir(img.basedir):
                     os.system("rm -fr " + img.basedir + '/*')
-            if not os.path.isdir(img.basedir):
-                os.makedirs(img.basedir)
-
-            # Now add solname (if any) and time to basedir
-            if img.opts.solnname is not None:
-                img.basedir += img.opts.solnname + '_'
-            img.basedir += time.strftime("%d%b%Y_%H.%M.%S")
 
             # Make the final output directory
-            if not os.path.isdir(img.basedir):
+            if not os.path.exists(img.basedir):
                 os.makedirs(img.basedir)
 
         del data
@@ -237,15 +225,12 @@ class Op_readimage(Op):
                 s1 = self.angdist2pixdist(img, bmaj, bpa, location=location)
                 s2 = self.angdist2pixdist(img, bmin, bpa + 90.0, location=location)
                 th = bpa + brot
-                if s1 < s2:
-                    s1, s2 = s2, s1
-                    th += 90.0
-                th = divmod(th, 180)[1] ### th lies between 0 and 180
+                s1, s2, th = func.fix_gaussian_axes(s1, s2, th)
                 return (s1, s2, th)
             else:
                 return img.beam2pix(x)
 
-        def pix2gaus(x, location=None, use_wcs=True):
+        def pix2gaus(x, location=None, use_wcs=True, is_error=False):
             """ Converts Gaussian parameters in pixels to deg.
 
             x - (maj [pix], min [pix], pa [deg])
@@ -253,24 +238,27 @@ class Op_readimage(Op):
                 transform is desired
             Input beam angle should be degrees CCW from the +y axis of the image.
             The output beam angle is degrees CCW from North.
+            Set is_error = True when x contains the errors on the parameters instead of
+                the parameters themselves.
             """
             if use_wcs:
                 s1, s2, th = x
                 if s1 == 0.0 and s2 == 0.0:
                     return (0.0, 0.0, 0.0)
-                brot = self.get_rot(img, location) # rotation delta CCW (in degrees) between N and +y axis of image
 
                 th_rad = th / 180.0 * N.pi
                 bmaj = self.pixdist2angdist(img, s1, th, location=location)
                 bmin = self.pixdist2angdist(img, s2, th + 90.0, location=location)
-                bpa = th - brot
-                if bmaj < bmin:
-                    bmaj, bmin = bmin, bmaj
-                    bpa += 90.0
-                bpa = divmod(bpa, 180)[1] ### bpa lies between 0 and 180
+                bpa = th
+                if not is_error:
+                    # Adjust the PA by the rotation delta and fix cases where
+                    # major and minor axes are swapped
+                    brot = self.get_rot(img, location) # rotation delta CCW (in degrees) between N and +y axis of image
+                    bpa = th - brot
+                    bmaj, bmin, bpa = func.fix_gaussian_axes(bmaj, bmin, bpa)
                 return (bmaj, bmin, bpa)
             else:
-                return img.pix2beam(x)
+                return img.pix2beam(x, is_error=is_error)
 
         def pix2coord(pix, location=None, use_wcs=True):
             """Converts size along x and y (in pixels) to size in RA and Dec (in degrees)
@@ -341,21 +329,21 @@ class Op_readimage(Op):
             th = bpa
             return (s1, s2, th)
 
-        def pix2beam(x):
+        def pix2beam(x, is_error=False):
             """ Converts beam in pixels to deg. Use when no dependence on
             position is appropriate.
 
             Input beam angle should be degrees CCW from the +y axis of the image.
             The output beam angle is degrees CCW from North at image center.
+            Set is_error = True when x contains the errors on the parameters instead of
+                the parameters themselves.
             """
             s1, s2, th = x
             bmaj = abs(s1 * cdelt1)
             bmin = abs(s2 * cdelt2)
             bpa = th
-            if bmaj < bmin:
-                bmaj, bmin = bmin, bmaj
-                bpa += 90.0
-            bpa = divmod(bpa, 180)[1] ### bpa lies between 0 and 180
+            if not is_error:
+                bmaj, bmin, bpa = func.fix_gaussian_axes(bmaj, bmin, bpa)
             return [bmaj, bmin, bpa]
 
         def pixel_beam():
@@ -378,23 +366,23 @@ class Op_readimage(Op):
                 found = True
             except:
                 ### try see if AIPS as put the beam in HISTORY as usual
-               for h in hdr['HISTORY']:
-                  # Check if h is a string or a FITS Card object (long headers are
-                  # split into Cards as of PyFITS 3.0.4)
-                  if not isinstance(h, str):
-                    hstr = h.value
-                  else:
-                    hstr = h
-                  if N.all(['BMAJ' in hstr, 'BMIN' in hstr, 'BPA' in hstr, 'CLEAN' in hstr]):
-                    try:
-                        dum, dum, dum, bmaj, dum, bmin, dum, bpa = hstr.split()
-                    except ValueError:
+                for h in hdr['HISTORY']:
+                    # Check if h is a string or a FITS Card object (long headers are
+                    # split into Cards as of PyFITS 3.0.4)
+                    if not isinstance(h, str):
+                        hstr = h.value
+                    else:
+                        hstr = h
+                    if N.all(['BMAJ' in hstr, 'BMIN' in hstr, 'BPA' in hstr, 'CLEAN' in hstr]):
                         try:
-                            dum, dum, bmaj, dum, bmin, dum, bpa, dum, dum = hstr.split()
+                            dum, dum, dum, bmaj, dum, bmin, dum, bpa = hstr.split()
                         except ValueError:
-                            break
-                    beam = (float(bmaj), float(bmin), float(bpa))
-                    found = True
+                            try:
+                                dum, dum, bmaj, dum, bmin, dum, bpa, dum, dum = hstr.split()
+                            except ValueError:
+                                break
+                        beam = (float(bmaj), float(bmin), float(bpa))
+                        found = True
             if not found: raise RuntimeError("No beam information found in image header.")
 
         ### convert beam into pixels (at image center)
@@ -570,8 +558,6 @@ class Op_readimage(Op):
         pa - position angle in degrees east of north
         location - x and y location of center
         """
-        from . import functions as func
-
         if location is None:
             x1 = int(img.image_arr.shape[2] / 2.0)
             y1 = int(img.image_arr.shape[3] / 2.0)
@@ -602,8 +588,6 @@ class Op_readimage(Op):
         pa - position angle in degrees CCW from +y axis
         location - x and y location of center
         """
-        from . import functions as func
-
         if location is None:
             x1 = int(img.image_arr.shape[2] / 2.0)
             y1 = int(img.image_arr.shape[3] / 2.0)
